
#ifndef WINDOW_H
#define WINDOW_H

#include "../interface.h"
//#include "uidialog.h" //ooo
#include "ui_uidialog.h"    //xxx

//class Window : public uiDialog    //ooo
class Window : public QDialog, public Ui::uiDialog	//xxx
{
    Q_OBJECT

public:
           Window ( QWidget *parent = 0 );
  virtual ~Window ( );

protected slots:
  virtual void slotBrowse ( );

protected:
  bool loadPlugin   ( );
  void unloadPlugin ( );

private:
  void           *m_pLibrary;
  destroyJHead_t *m_pDestroyFunction;
  jhead::JHead   *m_pPlugin;
};

#endif
